# 📝 Changelog

[![PyPI version](https://badge.fury.io/py/pcileech-fw-generator.svg)](https://badge.fury.io/py/pcileech-fw-generator)
[![Python Support](https://img.shields.io/pypi/pyversions/pcileech-fw-generator.svg)](https://pypi.org/project/pcileech-fw-generator/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

All notable changes to the PCILeech Firmware Generator will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v0.5.0.html).

---

## 📑 Table of Contents

- [Version 0.13.36 (2025-09-29)](#version-01336-2025-09-29)
- [Version 0.13.35 (2025-09-26)](#version-01335-2025-09-26)
- [Version 0.13.34 (2025-09-25)](#version-01334-2025-09-25)
- [Version 0.13.33 (2025-09-24)](#version-01333-2025-09-24)
- [Version 0.13.32 (2025-09-24)](#version-01332-2025-09-24)
- [Version 0.13.31 (2025-09-23)](#version-01331-2025-09-23)
- [Version 0.13.30 (2025-09-23)](#version-01330-2025-09-23)
- [Version 0.13.29 (2025-09-22)](#version-01329-2025-09-22)
- [Version 0.13.28 (2025-09-22)](#version-01328-2025-09-22)
- [Version 0.13.27 (2025-09-22)](#version-01327-2025-09-22)
- [Version 0.13.26 (2025-09-21)](#version-01326-2025-09-21)
- [Version 0.13.25 (2025-09-20)](#version-01325-2025-09-20)
- [Version 0.13.24 (2025-09-17)](#version-01324-2025-09-17)
- [Version 0.13.23 (2025-09-16)](#version-01323-2025-09-16)
- [Version 0.13.22 (2025-09-16)](#version-01322-2025-09-16)
- [Version 0.13.21 (2025-09-15)](#version-01321-2025-09-15)
- [Version 0.13.20 (2025-09-12)](#version-01320-2025-09-12)
- [Version 0.13.19 (2025-09-11)](#version-01319-2025-09-11)
- [Version 0.13.18 (2025-09-10)](#version-01318-2025-09-10)
- [Version 0.13.17 (2025-09-08)](#version-01317-2025-09-08)
- [Version 0.13.16 (2025-09-06)](#version-01316-2025-09-06)
- [Version 0.13.15 (2025-09-06)](#version-01315-2025-09-06)
- [Version 0.13.14 (2025-09-06)](#version-01314-2025-09-06)
- [Version 0.13.13 (2025-09-06)](#version-01313-2025-09-06)
- [Version 0.13.12 (2025-09-04)](#version-01312-2025-09-04)
- [Version 0.13.11 (2025-09-03)](#version-01311-2025-09-03)
- [Version 0.13.10 (2025-09-03)](#version-01310-2025-09-03)
- [Version 0.13.9 (2025-09-03)](#version-0139-2025-09-03)
- [Version 0.13.8 (2025-08-24)](#version-0138-2025-08-24)
- [Version 0.13.7 (2025-08-23)](#version-0137-2025-08-23)
- [Version 0.13.6 (2025-08-22)](#version-0136-2025-08-22)
- [Version 0.13.5 (2025-08-22)](#version-0135-2025-08-22)
- [Version 0.13.4 (2025-08-16)](#version-0134-2025-08-16)
- [Version 0.5.8 (2025-06-09)](#020---2025-06-09)

---
## Version 0.13.36 (2025-09-29)

### Bug Fixes

- Fix nettype warning and pcileech_tlps128_cfgspace_shadow.

### Other

- Unit tests (#410).

---
## Version 0.13.35 (2025-09-26)

### Bug Fixes

- Fix and clean log output.

---
## Version 0.13.34 (2025-09-25)

Minor updates and improvements.

---
## Version 0.13.33 (2025-09-24)

### Bug Fixes

- Fix.
- Fixes.
- Fixes.

---
## Version 0.13.32 (2025-09-24)

### Bug Fixes

- Fix.
- Fixes.
- Fixes.

---
## Version 0.13.31 (2025-09-23)

### Bug Fixes

- Fixes.

---
## Version 0.13.30 (2025-09-23)

### Bug Fixes

- Fix.

---
## Version 0.13.29 (2025-09-22)

### Bug Fixes

- Fix.

### Other

- Template bugs.

---
## Version 0.13.28 (2025-09-22)

### Bug Fixes

- Fix part regression.

---
## Version 0.13.27 (2025-09-22)

### Other

- Clean this error up.
- Improved test coverage.

---
## Version 0.13.26 (2025-09-21)

### Other

- ..

---
## Version 0.13.25 (2025-09-20)

### Other

- 389 bug 01324 (#390).
- :arrow_up:(deps): Bump actions/checkout from 4 to 5 (#290).

---
## Version 0.13.24 (2025-09-17)

### Other

- Add missing module.

---
## Version 0.13.23 (2025-09-16)

### Other

- Update tests.
- Cleanup duplicated context code.
- Cleanup duplicated context code.
- Cleanup duplicated context code.

---
## Version 0.13.22 (2025-09-16)

### Other

- Update tests.
- Stability fixes.

---
## Version 0.13.21 (2025-09-15)

### Bug Fixes

- Fix and isort (#382).
- Fix and isort (#381).

---
## Version 0.13.20 (2025-09-12)

### Other

- ..
- ..
- ..
- :arrow_up:(deps): Bump codecov/codecov-action from 4 to 5 (#324).
- :arrow_up:(deps): Bump actions/github-script from 7 to 8 (#369).

---
## Version 0.13.19 (2025-09-11)

### Other

- Allow visible register changes (#374).

---
## Version 0.13.18 (2025-09-10)

### Other

- Isort, bump test coverage.
- :arrow_up:(deps): Bump actions/setup-python from 5 to 6 (#370).

---
## Version 0.13.17 (2025-09-08)

### Other

- ..
- ..
- Update src/device_clone/pcileech_generator.py.
- ..

---
## Version 0.13.16 (2025-09-06)

### Other

- Nitpick.
- Clean generator code.
- Improve error injection and add pc control feature (#362).
- Default on (#361).
- Generate BAR entrophy (#360).

---
## Version 0.13.15 (2025-09-06)

Minor updates and improvements.

---
## Version 0.13.14 (2025-09-06)

### Bug Fixes

- Fix some cycles.
- Fix ci and integrate kernel driver.
- Fixes (#341).

### Other

- Isort.
- Uniform project name.
- Improve msix context.

---
## Version 0.13.13 (2025-09-06)

### Bug Fixes

- Fix some cycles.
- Fix ci and integrate kernel driver.
- Fixes (#341).

### Other

- Isort.
- Uniform project name.
- Improve msix context.

---
## Version 0.13.12 (2025-09-04)

### Bug Fixes

- Fix msix recollection.

---
## Version 0.13.11 (2025-09-03)

### Other

- Bump vers.

---
## Version 0.13.10 (2025-09-03)

Minor updates and improvements.

---
## Version 0.13.9 (2025-09-03)

### Bug Fixes

- Fix i/o port handling (#332).
- Fix msix context (#329).

### Other

- :arrow_up:(deps): Bump actions/ai-inference from 1 to 2 (#291).
- :arrow_up:(deps): Bump actions/download-artifact from 4 to 5 (#325).

---
## Version 0.13.8 (2025-08-24)

Minor updates and improvements.

---
## Version 0.13.7 (2025-08-23)

### Other

- ..
- ..

---
## Version 0.13.6 (2025-08-22)

### Bug Fixes

- Fix a couple tests.
- Fix missing context values.

### Other

- Potential fix for code scanning alert no. 149: Overly permissive file permissions (#312).
- Potential fix for code scanning alert no. 150: Overly permissive file permissions (#311).
- Potential fix for code scanning alert no. 252: Unhashable object hashed (#310).
- Potential fix for code scanning alert no. 248: Wrong number of arguments in a class instantiation (#309).
- Update project url (#308).

---
## Version 0.13.5 (2025-08-22)

### Other

- Consolidate contexts (#281).

---
## Version 0.13.4 (2025-08-16)

lots of stuff

---
## Version 0.7.5 (2025-06-09)

- Added TUI integration tests using `textual.testing`.

---

## Version 0.5.8 (2025-06-09)

Some templating fixes and pypi formatting fixes

--- 


